@@ -22,8 +22,14 @@ class CommandsRouting:
 
     def route(self):
         if self.arguments.alias is None:
-              print("Missing alias/option!!")
-              subprocess.call(['e2e_cli', '-h'])
+                Py_version_manager.py_print( "usage: e2e_cli {doc, alias, @<alias>}")
+                Py_version_manager.py_print()
+                Py_version_manager.py_print("E2E CLI")
+                Py_version_manager.py_print()
+                Py_version_manager.py_print( "Commands/Options:")
+                Py_version_manager.py_print( "    doc                 To view detailed man doc")
+                Py_version_manager.py_print( "    alias               To add/delete api key and auth tokens")
+                Py_version_manager.py_print( "    @<alias>            To access services using CLI")
 
 
         elif self.arguments.alias == "doc":
@@ -35,6 +41,8 @@ class CommandsRouting:
             if(self.arguments.command not in ["add", "view","add_file","delete"]):
                 Py_version_manager.py_print( "usage: e2e_cli alias {add, view, add_file, delete}")
                 Py_version_manager.py_print()
+                Py_version_manager.py_print("E2E CLI")
+                Py_version_manager.py_print()
                 Py_version_manager.py_print( "alias commands:")
                 Py_version_manager.py_print( "    add                 To add api key and auth token")
                 Py_version_manager.py_print( "    add_file            To add api key and auth token via file")
@@ -52,7 +60,7 @@ class CommandsRouting:
         elif (self.arguments.alias[0]=="@"):
 
             if (self.arguments.command is None):
-                print("issue in command/Wrong command given!!")
+                Py_version_manager.py_print("issue in command/Wrong command given!!")
                 subprocess.call(['e2e_cli', 'alias','-h'])
 
             elif self.arguments.command == "node":
@@ -120,5 +128,6 @@ class CommandsRouting:
                             
         else :
               Py_version_manager.py_print("Command not found")
+              Py_version_manager.py_print("Did you mean, e2e_cli doc --> for viewing man doc ??")
               Py_version_manager.py_print("Did you mean, e2e_cli alias [command] --> for adding alias ??")
               Py_version_manager.py_print("Did you mean, e2e_cli @<alias> [command] [sub-command] --> for accessing services ??")
\ No newline at end of file
