@@ -7,6 +7,7 @@ from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.request_service import Request
 from e2e_cli.core.alias_service import AliasServices
 from e2e_cli.core.helper_service import Checks
+from e2e_cli.core.constants import BASE_URL
 from e2e_cli.node.node_crud.node import NodeCrud
 
 
@@ -549,7 +550,7 @@ class LBServices:
         if api_key_credentials_object["message"] == "Invalid alias provided":
             return api_key_credentials_object
         else:
-            url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/?location=Delhi&apikey=" + \
+            url =  BASE_URL+"myaccount/api/v1/appliances/?location=Delhi&apikey=" + \
                   api_key_credentials_object["api_credentials"]["api_key"]
             payload = {}
             method = "GET"
@@ -629,7 +630,7 @@ class LBServices:
                 payload = self.classic_lb_creation(api_key_credentials_object["api_credentials"]["api_key"],
                                                    api_key_credentials_object["api_credentials"]["api_auth_token"], [],
                                                    plan_assigned_to_lb)
-                url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/load-balancers/" \
+                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" \
                       "?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_object = Request(req="POST", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -640,7 +641,7 @@ class LBServices:
                 payload = self.advance_lb_creation(api_key_credentials_object["api_credentials"]["api_key"],
                                                    api_key_credentials_object["api_credentials"]["api_auth_token"], [],
                                                    [], [], plan_assigned_to_lb)
-                url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/load-balancers/" \
+                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" \
                       "?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_object = Request(req="POST", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -663,7 +664,7 @@ class LBServices:
                 return api_key_credentials_object
             else:
 
-                url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/" + lb_id + "/?apikey=" + \
+                url =  BASE_URL+"myaccount/api/v1/appliances/" + lb_id + "/?apikey=" + \
                       api_key_credentials_object["api_credentials"]["api_key"]
 
                 payload = {}
@@ -792,7 +793,7 @@ class LBServices:
             edit_choice = Py_version_manager.py_input(": ")
             if edit_choice == str(1):
                 json_payload = self.change_lb_name()
-                url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/load-balancers/" + \
+                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" + \
                       lb_id + "/actions/?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_obj = Request(req="PUT", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -801,7 +802,7 @@ class LBServices:
                         "message": api_key_credentials_object["message"]}
             elif edit_choice == str(2):
                 json_payload = self.change_port_node(all_lb_in_list["appliance_instance"])
-                url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/load-balancers/" + \
+                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" + \
                       lb_id + "/?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_obj = Request(req="PUT", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -811,7 +812,7 @@ class LBServices:
 
             elif edit_choice == str(3):
                 json_payload = self.add_new_node(all_lb_in_list["appliance_instance"], api_key_credentials_object)
-                url = "https://api.e2enetworks.com/myaccount/api/v1/appliances/load-balancers/" + \
+                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" + \
                       lb_id + "/?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_obj = Request(req="PUT", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
