@@ -13,13 +13,6 @@ class Main:
         format_string = "e2e_cli" + " alias"+ " " + action + " [-h]" + " {create,delete,list,edit/update} ... "
         parser.usage = format_string
 
-    def FormatUsageCommand(self, parser, action, command):
-        format_string = "e2e_cli" + " alias"+ " " + action + " [-h] " + command
-        subparser_list = list(parser._subparsers._group_actions[0].choices.keys())
-        subparser_string = "{ " + reduce(lambda a, b: a + ", " + b, subparser_list) + " }"
-        format_string = "e2e_cli" + " alias=" + "<alias_name>"+ " " + action + " [-h]" + " " + subparser_string
-        parser.usage = format_string
-
     def FormatUsageCommand(self, parser, action, command):
         format_string = "e2e_cli" + " alias=" + "<alias_name>"+ " " + action + " [-h] " + command
         parser.usage = format_string
@@ -136,7 +129,7 @@ class Main:
 class ArgPaser(argparse.ArgumentParser):
     def error(self, message):
         args = {'prog': self.prog, 'message': message}
-        print( args["message"])
+        Py_version_manager.py_print( args["message"])
 
 
 def commanding(parser):
